@@ -81,8 +81,8 @@ class InteropExtractionMetrics(InteropBinParser):
         #self.idf = self.make_coordinate_plane(self.df)
 
     def __str__(self): 
-        #TODO: better printout
-        out = '%s' % self.df.head()
+        #TODO: to_str (improve output)
+        out = "%s\n" % self.df.head()
         return out
 
 if __name__=='__main__':
